@@ -20,13 +20,14 @@ More WMS basemaps can be found at the following websites:
 
 import collections
 import os
+from typing import Dict, Any
 import requests
 import folium
 import ipyleaflet
 import xyzservices
-from .common import check_package, planet_tiles
+from .common import check_package, planet_tiles, GoogleMapsTileProvider
 
-GOOGLE_MAPS_API_KEY = os.environ.get("GOOGLE_MAPS_API_KEY", "YOUR-API-KEY")
+GOOGLE_MAPS_API_KEY = os.environ.get("GOOGLE_MAPS_API_KEY", None)
 
 XYZ_TILES = {
     "OpenStreetMap": {
@@ -37,29 +38,13 @@ XYZ_TILES = {
 }
 
 # Add Google basemaps if API key is detected in the environment variables.
-if GOOGLE_MAPS_API_KEY != "":
+if GOOGLE_MAPS_API_KEY is not None:
     XYZ_TILES.update(
         {
-            "ROADMAP": {
-                "url": f"https://mt1.google.com/vt/lyrs=m&x={{x}}&y={{y}}&z={{z}}&key={GOOGLE_MAPS_API_KEY}",
-                "attribution": "Google",
-                "name": "Google Maps",
-            },
-            "SATELLITE": {
-                "url": f"https://mt1.google.com/vt/lyrs=s&x={{x}}&y={{y}}&z={{z}}&key={GOOGLE_MAPS_API_KEY}",
-                "attribution": "Google",
-                "name": "Google Satellite",
-            },
-            "TERRAIN": {
-                "url": f"https://mt1.google.com/vt/lyrs=p&x={{x}}&y={{y}}&z={{z}}&key={GOOGLE_MAPS_API_KEY}",
-                "attribution": "Google",
-                "name": "Google Terrain",
-            },
-            "HYBRID": {
-                "url": f"https://mt1.google.com/vt/lyrs=y&x={{x}}&y={{y}}&z={{z}}&key={GOOGLE_MAPS_API_KEY}",
-                "attribution": "Google",
-                "name": "Google Hybrid",
-            },
+            "ROADMAP": GoogleMapsTileProvider(map_type="roadmap"),
+            "SATELLITE": GoogleMapsTileProvider(map_type="satellite"),
+            "TERRAIN": GoogleMapsTileProvider(map_type="terrain"),
+            "HYBRID": GoogleMapsTileProvider(map_type="hybrid"),
         }
     )
 else:  # If Google Maps API key is not detected, defaulting to Esri basemaps.
@@ -92,7 +77,7 @@ else:  # If Google Maps API key is not detected, defaulting to Esri basemaps.
 # Custom WMS tile services.
 WMS_TILES = {
     "FWS NWI Wetlands": {
-        "url": "https://www.fws.gov/wetlandsmapservice/services/Wetlands/MapServer/WMSServer?",
+        "url": "https://fwspublicservices.wim.usgs.gov/wetlandsmapservice/services/Wetlands/MapServer/WMSServer?",
         "layers": "1",
         "name": "FWS NWI Wetlands",
         "attribution": "FWS",
@@ -182,7 +167,7 @@ WMS_TILES = {
     },
     "USGS NAIP Imagery": {
         "url": "https://imagery.nationalmap.gov/arcgis/services/USGSNAIPImagery/ImageServer/WMSServer?",
-        "layers": "USGSNAIPImagery:NaturalColor",
+        "layers": "USGSNAIPImagery",
         "name": "USGS NAIP Imagery",
         "attribution": "USGS",
         "format": "image/png",
@@ -276,6 +261,14 @@ WMS_TILES = {
         "format": "image/png",
         "transparent": True,
     },
+    "USGS.Imagery": {
+        "url": "https://basemap.nationalmap.gov/arcgis/services/USGSImageryOnly/MapServer/WMSServer?",
+        "layers": "0",
+        "name": "USGS.Imagery",
+        "attribution": "USGS",
+        "format": "image/png",
+        "transparent": True,
+    },
 }
 
 custom_tiles = {"xyz": XYZ_TILES, "wms": WMS_TILES}
@@ -474,26 +467,22 @@ def xyz_to_bokeh():
     """
     from bokeh.models import WMTSTileSource
 
-    bokeh_dict = {}
+    bokeh_dict: Dict[str, WMTSTileSource] = {}
 
-    for key in XYZ_TILES:
-        url = XYZ_TILES[key]["url"]
-        attribution = XYZ_TILES[key]["attribution"]
-        tile_options = {
+    for key, tile_info in XYZ_TILES.items():
+        if "url" not in tile_info or "attribution" not in tile_info:
+            raise ValueError(
+                f"Invalid tile configuration for key {key}. Missing 'url' or attribution."
+            )
+
+        url: str = tile_info["url"]
+        attribution: str = tile_info["attribution"]
+
+        tile_options: Dict[str, Any] = {
             "url": url,
             "attribution": attribution,
         }
-        bokeh_dict[key] = WMTSTileSource(**tile_options)
 
-    xyz_dict = get_xyz_dict()
-    for item in xyz_dict:
-        url = xyz_dict[item].build_url()
-        attribution = xyz_dict[item].attribution
-        key = xyz_dict[item].name
-        tile_options = {
-            "url": url,
-            "attribution": attribution,
-        }
         bokeh_dict[key] = WMTSTileSource(**tile_options)
 
     return bokeh_dict
