@@ -5,9 +5,52 @@ from bokeh.models import WheelZoomTool, WMTSTileSource, GeoJSONDataSource, Hover
 from bokeh.plotting import figure, show, save
 from bokeh.io import output_notebook
 from .basemaps import xyz_to_bokeh
-from .common import *
+from . import common
 from typing import Optional, List, Dict
 
+from .common import (
+    add_crs,
+    basemap_xyz_tiles,
+    cog_bands,
+    cog_bounds,
+    cog_center,
+    cog_tile,
+    convert_lidar,
+    csv_to_df,
+    csv_to_geojson,
+    csv_to_shp,
+    download_file,
+    download_from_url,
+    download_ned,
+    gdf_to_geojson,
+    get_api_key,
+    get_census_dict,
+    image_to_numpy,
+    netcdf_to_tif,
+    numpy_to_cog,
+    planet_monthly_tiles,
+    planet_quarterly_tiles,
+    planet_tiles,
+    plot_raster,
+    plot_raster_3d,
+    pmtiles_metadata,
+    pmtiles_style,
+    read_lidar,
+    read_netcdf,
+    search_qms,
+    search_xyz_services,
+    set_api_key,
+    stac_assets,
+    stac_bands,
+    stac_bounds,
+    stac_center,
+    stac_info,
+    stac_stats,
+    stac_tile,
+    view_lidar,
+    write_lidar,
+)
+
 os.environ["OUTPUT_NOTEBOOK"] = "False"
 basemaps = Box(xyz_to_bokeh(), frozen_box=True)
 
@@ -36,9 +79,9 @@ class Map:
             kwargs["height"] = height
 
         if "x_range" not in kwargs:
-            kwargs["x_range"] = center_zoom_to_xy_range(center, zoom)[0]
+            kwargs["x_range"] = common.center_zoom_to_xy_range(center, zoom)[0]
         if "y_range" not in kwargs:
-            kwargs["y_range"] = center_zoom_to_xy_range(center, zoom)[1]
+            kwargs["y_range"] = common.center_zoom_to_xy_range(center, zoom)[1]
 
         fig = figure(**kwargs)
         self.figure = fig
@@ -47,7 +90,7 @@ class Map:
             if basemap == "OpenStreetMap":
                 try:
                     fig.add_tile(xyz.OpenStreetMap.Mapnik, retina=True)
-                except:
+                except Exception:
                     from bokeh.tile_providers import get_provider
 
                     fig.add_tile(get_provider(xyz.OpenStreetMap.Mapnik))
@@ -122,7 +165,7 @@ class Map:
         """
         try:
             self.figure.add_tile(tile, **kwargs)
-        except Exception as e:
+        except Exception:
             if "retina" in kwargs.keys():
                 kwargs.pop("retina")
             self.figure.add_tile(tile, **kwargs)
@@ -143,14 +186,14 @@ class Map:
             url (str): The URL of the COG tile layer.
             attribution (str, optional): The attribution to use. Defaults to ''.
             bands (list, optional): A list of bands to use for the layer. Defaults to None.
-            titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://titiler.xyz".
+            titiler_endpoint (str, optional): TiTiler endpoint. Defaults to "https://giswqs-titiler-endpoint.hf.space".
             cog_args: Arbitrary keyword arguments, including bidx, expression, nodata, unscale, resampling, rescale,
                 color_formula, colormap, colormap_name, return_mask. See https://developmentseed.org/titiler/endpoints/cog/
                 and https://cogeotiff.github.io/rio-tiler/colormap/. To select a certain bands, use bidx=[1, 2, 3].
                 apply a rescaling to multiple bands, use something like `rescale=["164,223","130,211","99,212"]`.
             **kwargs: Arbitrary keyword arguments for bokeh.figure.add_tile() function, such as alpha, visible, etc.
         """
-        tile_url = cog_tile(url, bands, titiler_endpoint, **cog_args)
+        tile_url = common.cog_tile(url, bands, titiler_endpoint, **cog_args)
         tile_options = {
             "url": tile_url,
             "attribution": attribution,
@@ -159,7 +202,7 @@ class Map:
         self.figure.add_tile(tile_source, **kwargs)
 
         if fit_bounds:
-            self.fit_bounds(cog_bounds(url, titiler_endpoint))
+            self.fit_bounds(common.cog_bounds(url, titiler_endpoint))
 
     def add_raster(
         self,
@@ -197,9 +240,9 @@ class Map:
         """
 
         if source.startswith("http"):
-            source = download_file(source)
+            source = common.download_file(source)
 
-        tile_layer, client = get_local_tile_layer(
+        tile_layer, client = common.get_local_tile_layer(
             source,
             indexes=indexes,
             colormap=colormap,
@@ -245,14 +288,14 @@ class Map:
             item (str): The Microsoft Planetary Computer STAC item ID, e.g., LC08_L2SP_047027_20201204_02_T1.
             assets (str | list): The Microsoft Planetary Computer STAC asset ID, e.g., ["SR_B7", "SR_B5", "SR_B4"].
             bands (list): A list of band names, e.g., ["SR_B7", "SR_B5", "SR_B4"]
-            titiler_endpoint (str, optional): TiTiler endpoint, e.g., "https://titiler.xyz", "https://planetarycomputer.microsoft.com/api/data/v1", "planetary-computer", "pc". Defaults to None.
+            titiler_endpoint (str, optional): TiTiler endpoint, e.g., "https://giswqs-titiler-endpoint.hf.space", "https://planetarycomputer.microsoft.com/api/data/v1", "planetary-computer", "pc". Defaults to None.
             attribution (str, optional): The attribution to use. Defaults to ''.
             fit_bounds (bool, optional): Whether to fit the map bounds to the raster bounds. Defaults to True.
             open_args: Arbitrary keyword arguments for get_local_tile_layer(). Defaults to {}.
             **kwargs: Arbitrary keyword arguments for bokeh.figure.add_tile() function, such as alpha, visible, etc.
 
         """
-        tile_url = stac_tile(
+        tile_url = common.stac_tile(
             url, collection, item, assets, bands, titiler_endpoint, **open_args
         )
         tile_options = {
@@ -263,7 +306,7 @@ class Map:
         self.figure.add_tile(tile_source, **kwargs)
 
         if fit_bounds:
-            self.fit_bounds(stac_bounds(url, collection, item, titiler_endpoint))
+            self.fit_bounds(common.stac_bounds(url, collection, item, titiler_endpoint))
 
     def add_gdf(
         self,
@@ -287,7 +330,7 @@ class Map:
         if not isinstance(gdf, gpd.GeoDataFrame):
             raise TypeError("gdf must be a GeoDataFrame")
 
-        geom_type = gdf_geom_type(gdf)
+        geom_type = common.gdf_geom_type(gdf)
         gdf_new = gdf.to_crs(to_crs)
 
         columns = gdf_new.columns.to_list()
@@ -340,7 +383,7 @@ class Map:
         import geopandas as gpd
 
         if filename.startswith("http"):
-            filename = github_raw_url(filename)
+            filename = common.github_raw_url(filename)
 
         gdf = gpd.read_file(filename, encoding=encoding, **read_file_args)
         self.add_gdf(
@@ -374,7 +417,7 @@ class Map:
         import glob
 
         if filename.startswith("http"):
-            filename = github_raw_url(filename)
+            filename = common.github_raw_url(filename)
 
         if filename.startswith("http") and filename.endswith(".zip"):
             out_dir = os.path.abspath("./cache/shp")
@@ -382,7 +425,7 @@ class Map:
                 os.makedirs(out_dir)
             basename = os.path.basename(filename)
             output = os.path.join(out_dir, basename)
-            download_file(filename, output)
+            common.download_file(filename, output)
             files = list(glob.glob(os.path.join(out_dir, "*.shp")))
             if len(files) > 0:
                 filename = files[0]
@@ -425,7 +468,7 @@ class Map:
         import geopandas as gpd
 
         if filename.startswith("http"):
-            filename = github_raw_url(filename)
+            filename = common.github_raw_url(filename)
 
         if isinstance(filename, gpd.GeoDataFrame):
             gdf = filename
@@ -455,7 +498,7 @@ class Map:
             bounds (list): A list of bounds in the form of [xmin, ymin, xmax, ymax].
         """
 
-        bounds = bounds_to_xy_range(bounds)
+        bounds = common.bounds_to_xy_range(bounds)
 
         self.figure.x_range.start = bounds[0][0]
         self.figure.x_range.end = bounds[0][1]
