@@ -2,10 +2,11 @@ import os
 import numpy as np
 import pandas as pd
 import ipywidgets as widgets
+from IPython.display import display
 
 from .basemaps import xyz_to_plotly
-from .common import *
-from .osm import *
+from . import common
+from . import osm
 from . import examples
 from typing import Optional, List, Union, Dict, Tuple
 from pandas import DataFrame
@@ -45,7 +46,7 @@ class Canvas:
 
         map_widget = widgets.Output(layout=widgets.Layout(width=map_max_width))
         with map_widget:
-            display(map)
+            map_widget.append_display_data(map)
 
         self.map = map
         self.map_min_width = map_min_width
@@ -417,14 +418,14 @@ class Map(go.FigureWidget):
             attribution (str, optional): The attribution to use. Defaults to ''.
             opacity (float, optional): The opacity of the layer. Defaults to 1.
             bands (list, optional): The bands to use. Defaults to None.
-            titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://titiler.xyz".
+            titiler_endpoint (str, optional): TiTiler endpoint. Defaults to "https://giswqs-titiler-endpoint.hf.space".
             **kwargs: Arbitrary keyword arguments, including bidx, expression, nodata, unscale, resampling, rescale,
                 color_formula, colormap, colormap_name, return_mask. See https://developmentseed.org/titiler/endpoints/cog/
                 and https://cogeotiff.github.io/rio-tiler/colormap/. To select a certain bands, use bidx=[1, 2, 3].
                 apply a rescaling to multiple bands, use something like `rescale=["164,223","130,211","99,212"]`.
         """
-        tile_url = cog_tile(url, bands, titiler_endpoint, **kwargs)
-        center = cog_center(url, titiler_endpoint)  # (lon, lat)
+        tile_url = common.cog_tile(url, bands, titiler_endpoint, **kwargs)
+        center = common.cog_center(url, titiler_endpoint)  # (lon, lat)
         self.add_tile_layer(tile_url, name, attribution, opacity)
         self.set_center(lon=center[0], lat=center[1], zoom=10)
 
@@ -449,15 +450,15 @@ class Map(go.FigureWidget):
             items (str): The Microsoft Planetary Computer STAC item ID, e.g., LC08_L2SP_047027_20201204_02_T1.
             assets (str | list): The Microsoft Planetary Computer STAC asset ID, e.g., ["SR_B7", "SR_B5", "SR_B4"].
             bands (list): A list of band names, e.g., ["SR_B7", "SR_B5", "SR_B4"]
-            titiler_endpoint (str, optional): Titiler endpoint, e.g., "https://titiler.xyz", "planetary-computer", "pc". Defaults to None.
+            titiler_endpoint (str, optional): TiTiler endpoint, e.g., "https://giswqs-titiler-endpoint.hf.space", "planetary-computer", "pc". Defaults to None.
             name (str, optional): The layer name to use for the layer. Defaults to 'STAC Layer'.
             attribution (str, optional): The attribution to use. Defaults to ''.
             opacity (float, optional): The opacity of the layer. Defaults to 1.
         """
-        tile_url = stac_tile(
+        tile_url = common.stac_tile(
             url, collection, items, assets, bands, titiler_endpoint, **kwargs
         )
-        center = stac_center(url, collection, items, titiler_endpoint)
+        center = common.stac_center(url, collection, items, titiler_endpoint)
         self.add_tile_layer(tile_url, name, attribution, opacity)
         self.set_center(lon=center[0], lat=center[1], zoom=10)
 
@@ -474,13 +475,13 @@ class Map(go.FigureWidget):
 
         Args:
             url (str): HTTP URL to a MosaicJSON.
-            titiler_endpoint (str, optional): Titiler endpoint, e.g., "https://titiler.xyz". Defaults to None.
+            titiler_endpoint (str, optional): TiTiler endpoint, e.g., "https://giswqs-titiler-endpoint.hf.space". Defaults to None.
             name (str, optional): The layer name to use for the layer. Defaults to 'Mosaic Layer'.
             attribution (str, optional): The attribution to use. Defaults to ''.
             opacity (float, optional): The opacity of the layer. Defaults to 1.
         """
-        tile_url = mosaic_tile(url, titiler_endpoint, **kwargs)
-        center = mosaic_info(url, titiler_endpoint)["center"]
+        tile_url = common.mosaic_tile(url, titiler_endpoint, **kwargs)
+        center = common.mosaic_info(url, titiler_endpoint)["center"]
         self.add_tile_layer(tile_url, name, attribution, opacity)
         self.set_center(lon=center[0], lat=center[1], zoom=10)
 
@@ -507,7 +508,7 @@ class Map(go.FigureWidget):
         """
         if name is None:
             name = str(year) + "-" + str(month).zfill(2)
-        tile_url = planet_by_month(year, month, api_key, token_name)
+        tile_url = common.planet_by_month(year, month, api_key, token_name)
         self.add_tile_layer(
             tile_url, name=name, attribution=attribution, opacity=opacity
         )
@@ -535,7 +536,7 @@ class Map(go.FigureWidget):
         """
         if name is None:
             name = str(year) + "-" + "q" + str(quarter)
-        tile_url = planet_by_quarter(year, quarter, api_key, token_name)
+        tile_url = common.planet_by_quarter(year, quarter, api_key, token_name)
         self.add_tile_layer(
             tile_url, name=name, attribution=attribution, opacity=opacity
         )
@@ -578,7 +579,7 @@ class Map(go.FigureWidget):
             z (str, optional): Z value of the data. Defaults to None.
             colorscale (str, optional): Color scale of the data. Defaults to "Viridis".
         """
-        check_package("geopandas")
+        common.check_package("geopandas")
         import json
         import geopandas as gpd
 
@@ -628,12 +629,23 @@ class Map(go.FigureWidget):
         """
 
         if isinstance(data, str):
-            df = pd.read_csv(data)
+            try:
+                df = pd.read_csv(data)
+            except FileNotFoundError:
+                raise FileNotFoundError(f"file path {data} not found")
+            except Exception as other_error:
+                raise ValueError(f"failed load data from {data}: {other_error}")
         elif isinstance(data, pd.DataFrame):
             df = data
         else:
             raise ValueError("data must be a DataFrame or a file path.")
 
+        for column_data in [latitude, longitude, z]:
+            if column_data not in df.columns:
+                raise KeyError(
+                    f"column {column_data} not found, available columns {', '.join(df.columns)}"
+                )
+
         heatmap = go.Densitymapbox(
             lat=df[latitude],
             lon=df[longitude],
@@ -670,7 +682,7 @@ class Map(go.FigureWidget):
         color_continuous_scale: Optional[str] = "Viridis",
         **kwargs,
     ) -> None:
-        check_package("geopandas", "https://geopandas.org")
+        common.check_package("geopandas", "https://geopandas.org")
         import geopandas as gpd
 
         geojson_url = str(gdf)
@@ -717,7 +729,7 @@ class Map(go.FigureWidget):
             color_col (str, optional): The column name of color. Defaults to None.
         """
 
-        check_package("geopandas", "https://geopandas.org")
+        common.check_package("geopandas", "https://geopandas.org")
         import geopandas as gpd
 
         if isinstance(gdf, str):
@@ -728,7 +740,7 @@ class Map(go.FigureWidget):
 
         gdf = gdf.to_crs(epsg=4326)
         # geom_type = gdf_geom_type(gdf)
-        center_lon, center_lat = gdf_centroid(gdf)
+        center_lon, center_lat = common.gdf_centroid(gdf)
 
         if isinstance(label_col, str):
             gdf = gdf.set_index(label_col)
@@ -841,9 +853,9 @@ def fix_widget_error() -> None:
     Adopted from: https://github.com/plotly/plotly.py/issues/2570#issuecomment-738735816
     """
     import shutil
-    import pkg_resources
+    import importlib.resources
 
-    pkg_dir = os.path.dirname(pkg_resources.resource_filename("plotly", "plotly.py"))
+    pkg_dir = os.path.dirname(importlib.resources.files("plotly") / "plotly.py")
 
     basedatatypesPath = os.path.join(pkg_dir, "basedatatypes.py")
 
