@@ -1,8 +1,8 @@
 import os
 import pystac
 import requests
-from typing import Optional, Dict, List, Callable, Any, Tuple, Union
-from pandas import DataFrame
+from typing import Optional, Dict, List, Callable, Tuple, Union
+import pandas as pd
 
 
 class TitilerEndpoint:
@@ -14,10 +14,10 @@ class TitilerEndpoint:
         name: Optional[str] = "stac",
         TileMatrixSetId: Optional[str] = "WebMercatorQuad",
     ):
-        """Initialize the TitilerEndpoint object.
+        """Initialize the TiTilerEndpoint object.
 
         Args:
-            endpoint (str, optional): The endpoint of the titiler server. Defaults to "https://titiler.xyz".
+            endpoint (str, optional): The endpoint of the titiler server. Defaults to "https://giswqs-titiler-endpoint.hf.space".
             name (str, optional): The name to be used in the file path. Defaults to "stac".
             TileMatrixSetId (str, optional): The TileMatrixSetId to be used in the file path. Defaults to "WebMercatorQuad".
         """
@@ -120,7 +120,7 @@ def check_titiler_endpoint(titiler_endpoint: Optional[str] = None):
             if titiler_endpoint == "planetary-computer":
                 titiler_endpoint = PlanetaryComputerEndpoint()
         else:
-            titiler_endpoint = "https://titiler.xyz"
+            titiler_endpoint = "https://giswqs-titiler-endpoint.hf.space"
     elif titiler_endpoint in ["planetary-computer", "pc"]:
         titiler_endpoint = PlanetaryComputerEndpoint()
 
@@ -139,7 +139,7 @@ def cog_tile(
     Args:
         url (str): HTTP URL to a COG, e.g., https://opendata.digitalglobe.com/events/mauritius-oil-spill/post-event/2020-08-12/105001001F1B5B00/105001001F1B5B00.tif
         bands (list, optional): List of bands to use. Defaults to None.
-        titiler_endpoint (str, optional): TiTiler endpoint. Defaults to "https://titiler.xyz".
+        titiler_endpoint (str, optional): TiTiler endpoint. Defaults to "https://giswqs-titiler-endpoint.hf.space".
         **kwargs: Additional arguments to pass to the titiler endpoint. For more information about the available arguments, see https://developmentseed.org/titiler/endpoints/cog/#tiles.
             For example, to apply a rescaling to multiple bands, use something like `rescale=["164,223","130,211","99,212"]`.
 
@@ -152,7 +152,11 @@ def cog_tile(
 
     kwargs["url"] = url
 
-    band_names = cog_bands(url, titiler_endpoint)
+    try:
+        band_names = cog_bands(url, titiler_endpoint)
+    except Exception as e:
+        titiler_endpoint = "https://titiler.xyz"
+        band_names = cog_bands(url, titiler_endpoint)
 
     if isinstance(bands, str):
         bands = [bands]
@@ -181,8 +185,17 @@ def cog_tile(
     elif isinstance(kwargs["bidx"], int):
         kwargs["bidx"] = [kwargs["bidx"]]
 
+    if len(kwargs["bidx"]) == 1 and ("colormap" not in kwargs):
+        colormap = _get_image_colormap(url)
+        if colormap is not None:
+            kwargs["colormap"] = colormap
+
     if "rescale" not in kwargs and ("colormap" not in kwargs):
-        stats = cog_stats(url, titiler_endpoint)
+        try:
+            stats = cog_stats(url, titiler_endpoint)
+        except Exception as e:
+            titiler_endpoint = "https://titiler.xyz"
+            stats = cog_stats(url, titiler_endpoint)
 
         if "message" not in stats:
             try:
@@ -209,9 +222,19 @@ def cog_tile(
     if "default_vis" in kwargs.keys() and kwargs["default_vis"]:
         kwargs = {"url": url}
 
-    r = requests.get(
-        f"{titiler_endpoint}/cog/{TileMatrixSetId}/tilejson.json", params=kwargs
-    ).json()
+    try:
+        r = requests.get(
+            f"{titiler_endpoint}/cog/{TileMatrixSetId}/tilejson.json",
+            params=kwargs,
+            timeout=10,
+        ).json()
+    except Exception as e:
+        titiler_endpoint = "https://titiler.xyz"
+        r = requests.get(
+            f"{titiler_endpoint}/cog/{TileMatrixSetId}/tilejson.json",
+            params=kwargs,
+            timeout=10,
+        ).json()
     return r["tiles"][0]
 
 
@@ -227,7 +250,7 @@ def cog_tile_vmin_vmax(
     Args:
         url (str): HTTP URL to a COG, e.g., https://opendata.digitalglobe.com/events/mauritius-oil-spill/post-event/2020-08-12/105001001F1B5B00/105001001F1B5B00.tif
         bands (list, optional): List of bands to use. Defaults to None.
-        titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://titiler.xyz".
+        titiler_endpoint (str, optional): TiTiler endpoint. Defaults to "https://giswqs-titiler-endpoint.hf.space".
         percentile (bool, optional): Whether to use percentiles or not. Defaults to True.
     Returns:
         tuple: Returns the minimum and maximum values.
@@ -265,7 +288,7 @@ def cog_mosaic(
 
     Args:
         links (list): A list containing COG HTTP URLs.
-        titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://titiler.xyz".
+        titiler_endpoint (str, optional): TiTiler endpoint. Defaults to "https://giswqs-titiler-endpoint.hf.space".
         username (str, optional): User name for the titiler endpoint. Defaults to "anonymous".
         layername ([type], optional): Layer name to use. Defaults to None.
         overwrite (bool, optional): Whether to overwrite the layer name if existing. Defaults to False.
@@ -332,7 +355,7 @@ def cog_mosaic_from_file(
     Args:
         filepath (str): Local path or HTTP URL to the csv/txt file containing COG URLs.
         skip_rows (int, optional): The number of rows to skip in the file. Defaults to 0.
-        titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://titiler.xyz".
+        titiler_endpoint (str, optional): TiTiler endpoint. Defaults to "https://giswqs-titiler-endpoint.hf.space".
         username (str, optional): User name for the titiler endpoint. Defaults to "anonymous".
         layername ([type], optional): Layer name to use. Defaults to None.
         overwrite (bool, optional): Whether to overwrite the layer name if existing. Defaults to False.
@@ -370,7 +393,7 @@ def cog_bounds(
 
     Args:
         url (str): HTTP URL to a COG, e.g., https://opendata.digitalglobe.com/events/mauritius-oil-spill/post-event/2020-08-12/105001001F1B5B00/105001001F1B5B00.tif
-        titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://titiler.xyz".
+        titiler_endpoint (str, optional): TiTiler endpoint. Defaults to "https://giswqs-titiler-endpoint.hf.space".
 
     Returns:
         list: A list of values representing [left, bottom, right, top]
@@ -394,7 +417,7 @@ def cog_center(
 
     Args:
         url (str): HTTP URL to a COG, e.g., https://opendata.digitalglobe.com/events/mauritius-oil-spill/post-event/2020-08-12/105001001F1B5B00/105001001F1B5B00.tif
-        titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://titiler.xyz".
+        titiler_endpoint (str, optional): TiTiler endpoint. Defaults to "https://giswqs-titiler-endpoint.hf.space".
 
     Returns:
         tuple: A tuple representing (longitude, latitude)
@@ -413,7 +436,7 @@ def cog_bands(
 
     Args:
         url (str): HTTP URL to a COG, e.g., https://opendata.digitalglobe.com/events/mauritius-oil-spill/post-event/2020-08-12/105001001F1B5B00/105001001F1B5B00.tif
-        titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://titiler.xyz".
+        titiler_endpoint (str, optional): TiTiler endpoint. Defaults to "https://giswqs-titiler-endpoint.hf.space".
 
     Returns:
         list: A list of band names
@@ -439,19 +462,30 @@ def cog_stats(
 
     Args:
         url (str): HTTP URL to a COG, e.g., https://opendata.digitalglobe.com/events/mauritius-oil-spill/post-event/2020-08-12/105001001F1B5B00/105001001F1B5B00.tif
-        titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://titiler.xyz".
+        titiler_endpoint (str, optional): TiTiler endpoint. Defaults to "https://giswqs-titiler-endpoint.hf.space".
 
     Returns:
         list: A dictionary of band statistics.
     """
 
     titiler_endpoint = check_titiler_endpoint(titiler_endpoint)
-    r = requests.get(
-        f"{titiler_endpoint}/cog/statistics",
-        params={
-            "url": url,
-        },
-    ).json()
+    try:
+        r = requests.get(
+            f"{titiler_endpoint}/cog/statistics",
+            params={
+                "url": url,
+            },
+            timeout=10,
+        ).json()
+    except Exception as e:
+        titiler_endpoint = "https://titiler.xyz"
+        r = requests.get(
+            f"{titiler_endpoint}/cog/statistics",
+            params={
+                "url": url,
+            },
+            timeout=10,
+        ).json()
 
     return r
 
@@ -465,7 +499,7 @@ def cog_info(
 
     Args:
         url (str): HTTP URL to a COG, e.g., https://opendata.digitalglobe.com/events/mauritius-oil-spill/post-event/2020-08-12/105001001F1B5B00/105001001F1B5B00.tif
-        titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://titiler.xyz".
+        titiler_endpoint (str, optional): TiTiler endpoint. Defaults to "https://giswqs-titiler-endpoint.hf.space".
 
     Returns:
         list: A dictionary of band info.
@@ -476,12 +510,23 @@ def cog_info(
     if return_geojson:
         info = "info.geojson"
 
-    r = requests.get(
-        f"{titiler_endpoint}/cog/{info}",
-        params={
-            "url": url,
-        },
-    ).json()
+    try:
+        r = requests.get(
+            f"{titiler_endpoint}/cog/{info}",
+            params={
+                "url": url,
+            },
+            timeout=10,
+        ).json()
+    except Exception as e:
+        titiler_endpoint = "https://titiler.xyz"
+        r = requests.get(
+            f"{titiler_endpoint}/cog/{info}",
+            params={
+                "url": url,
+            },
+            timeout=10,
+        ).json()
 
     return r
 
@@ -502,7 +547,7 @@ def cog_pixel_value(
         lat (float): Latitude of the pixel.
         url (str): HTTP URL to a COG, e.g., 'https://github.com/opengeos/data/releases/download/raster/Libya-2023-07-01.tif'
         bidx (str, optional): Dataset band indexes (e.g bidx=1, bidx=1&bidx=2&bidx=3). Defaults to None.
-        titiler_endpoint (str, optional): Titiler endpoint, e.g., "https://titiler.xyz", "planetary-computer", "pc". Defaults to None.
+        titiler_endpoint (str, optional): TiTiler endpoint, e.g., "https://giswqs-titiler-endpoint.hf.space", "planetary-computer", "pc". Defaults to None.
         verbose (bool, optional): Print status messages. Defaults to True.
 
     Returns:
@@ -550,11 +595,12 @@ def stac_tile(
         item (str): The Microsoft Planetary Computer STAC item ID, e.g., LC08_L2SP_047027_20201204_02_T1.
         assets (str | list): The Microsoft Planetary Computer STAC asset ID, e.g., ["SR_B7", "SR_B5", "SR_B4"].
         bands (list): A list of band names, e.g., ["SR_B7", "SR_B5", "SR_B4"]
-        titiler_endpoint (str, optional): Titiler endpoint, e.g., "https://titiler.xyz", "https://planetarycomputer.microsoft.com/api/data/v1", "planetary-computer", "pc". Defaults to None.
+        titiler_endpoint (str, optional): TiTiler endpoint, e.g., "https://giswqs-titiler-endpoint.hf.space", "https://planetarycomputer.microsoft.com/api/data/v1", "planetary-computer", "pc". Defaults to None.
 
     Returns:
         str: Returns the STAC Tile layer URL.
     """
+    import json
 
     if url is None and collection is None:
         raise ValueError("Either url or collection must be specified.")
@@ -562,6 +608,12 @@ def stac_tile(
     if collection is not None and titiler_endpoint is None:
         titiler_endpoint = "planetary-computer"
 
+    if isinstance(url, pystac.Item):
+        try:
+            url = url.self_href
+        except Exception as e:
+            print(e)
+
     if url is not None:
         kwargs["url"] = url
     if collection is not None:
@@ -604,12 +656,22 @@ def stac_tile(
             and ("expression" not in kwargs)
             and ("rescale" not in kwargs)
         ):
-            stats = stac_stats(
-                collection=collection,
-                item=item,
-                assets=assets,
-                titiler_endpoint=titiler_endpoint,
-            )
+            try:
+                stats = stac_stats(
+                    collection=collection,
+                    item=item,
+                    assets=assets,
+                    titiler_endpoint=titiler_endpoint,
+                )
+            except Exception as e:
+                titiler_endpoint = "https://titiler.xyz"
+                stats = stac_stats(
+                    collection=collection,
+                    item=item,
+                    assets=assets,
+                    titiler_endpoint=titiler_endpoint,
+                )
+
             if "detail" not in stats:
                 try:
                     percentile_2 = min([stats[s]["percentile_2"] for s in stats])
@@ -655,21 +717,38 @@ def stac_tile(
                     assets = None
 
         else:
-            kwargs["asset_bidx"] = bands
+            if bands is not None:
+                kwargs["asset_bidx"] = bands
         if assets is not None:
             kwargs["assets"] = assets
 
+            if len(kwargs["assets"]) == 1 and ("colormap" not in kwargs):
+                cog_url = get_cog_link_from_stac_item(url)
+                colormap = _get_image_colormap(cog_url)
+                if colormap is not None:
+                    kwargs["colormap"] = colormap
+
         if (
             (assets is not None)
             and ("asset_expression" not in kwargs)
             and ("expression" not in kwargs)
             and ("rescale" not in kwargs)
+            and ("colormap" not in kwargs)
         ):
-            stats = stac_stats(
-                url=url,
-                assets=assets,
-                titiler_endpoint=titiler_endpoint,
-            )
+            try:
+                stats = stac_stats(
+                    url=url,
+                    assets=assets,
+                    titiler_endpoint=titiler_endpoint,
+                )
+            except Exception as e:
+                titiler_endpoint = "https://titiler.xyz"
+                stats = stac_stats(
+                    url=url,
+                    assets=assets,
+                    titiler_endpoint=titiler_endpoint,
+                )
+
             if "detail" not in stats:
                 try:
                     percentile_2 = min([stats[s]["percentile_2"] for s in stats])
@@ -696,18 +775,42 @@ def stac_tile(
         TileMatrixSetId = kwargs["TileMatrixSetId"]
         kwargs.pop("TileMatrixSetId")
 
+    if "colormap" in kwargs and isinstance(kwargs["colormap"], dict):
+        kwargs["colormap"] = json.dumps(kwargs["colormap"])
+
     if mosaic_json:
-        r = requests.get(
-            f"{titiler_endpoint}/mosaicjson/tilejson.json", params=kwargs
-        ).json()
+        try:
+            r = requests.get(
+                f"{titiler_endpoint}/mosaicjson/{TileMatrixSetId}/tilejson.json",
+                params=kwargs,
+                timeout=10,
+            ).json()
+        except Exception as e:
+            titiler_endpoint = "https://titiler.xyz"
+            r = requests.get(
+                f"{titiler_endpoint}/mosaicjson/{TileMatrixSetId}/tilejson.json",
+                params=kwargs,
+                timeout=10,
+            ).json()
     else:
         if isinstance(titiler_endpoint, str):
-            r = requests.get(
-                f"{titiler_endpoint}/stac/{TileMatrixSetId}/tilejson.json",
-                params=kwargs,
-            ).json()
+            try:
+                r = requests.get(
+                    f"{titiler_endpoint}/stac/{TileMatrixSetId}/tilejson.json",
+                    params=kwargs,
+                    timeout=10,
+                ).json()
+            except Exception as e:
+                titiler_endpoint = "https://titiler.xyz"
+                r = requests.get(
+                    f"{titiler_endpoint}/stac/{TileMatrixSetId}/tilejson.json",
+                    params=kwargs,
+                    timeout=10,
+                ).json()
         else:
-            r = requests.get(titiler_endpoint.url_for_stac_item(), params=kwargs).json()
+            r = requests.get(
+                titiler_endpoint.url_for_stac_item(), params=kwargs, timeout=10
+            ).json()
 
     return r["tiles"][0]
 
@@ -725,7 +828,7 @@ def stac_bounds(
         url (str): HTTP URL to a STAC item, e.g., https://canada-spot-ortho.s3.amazonaws.com/canada_spot_orthoimages/canada_spot5_orthoimages/S5_2007/S5_11055_6057_20070622/S5_11055_6057_20070622.json
         collection (str): The Microsoft Planetary Computer STAC collection ID, e.g., landsat-8-c2-l2.
         item (str): The Microsoft Planetary Computer STAC item ID, e.g., LC08_L2SP_047027_20201204_02_T1.
-        titiler_endpoint (str, optional): Titiler endpoint, e.g., "https://titiler.xyz", "planetary-computer", "pc". Defaults to None.
+        titiler_endpoint (str, optional): TiTiler endpoint, e.g., "https://giswqs-titiler-endpoint.hf.space", "planetary-computer", "pc". Defaults to None.
 
     Returns:
         list: A list of values representing [left, bottom, right, top]
@@ -737,6 +840,12 @@ def stac_bounds(
     if collection is not None and titiler_endpoint is None:
         titiler_endpoint = "planetary-computer"
 
+    if isinstance(url, pystac.Item):
+        try:
+            url = url.self_href
+        except Exception as e:
+            print(e)
+
     if url is not None:
         kwargs["url"] = url
         response = requests.get(url)
@@ -774,11 +883,18 @@ def stac_center(
         url (str): HTTP URL to a STAC item, e.g., https://canada-spot-ortho.s3.amazonaws.com/canada_spot_orthoimages/canada_spot5_orthoimages/S5_2007/S5_11055_6057_20070622/S5_11055_6057_20070622.json
         collection (str): The Microsoft Planetary Computer STAC collection ID, e.g., landsat-8-c2-l2.
         item (str): The Microsoft Planetary Computer STAC item ID, e.g., LC08_L2SP_047027_20201204_02_T1.
-        titiler_endpoint (str, optional): Titiler endpoint, e.g., "https://titiler.xyz", "planetary-computer", "pc". Defaults to None.
+        titiler_endpoint (str, optional): TiTiler endpoint, e.g., "https://giswqs-titiler-endpoint.hf.space", "planetary-computer", "pc". Defaults to None.
 
     Returns:
         tuple: A tuple representing (longitude, latitude)
     """
+
+    if isinstance(url, pystac.Item):
+        try:
+            url = url.self_href
+        except Exception as e:
+            print(e)
+
     bounds = stac_bounds(url, collection, item, titiler_endpoint, **kwargs)
     center = ((bounds[0] + bounds[2]) / 2, (bounds[1] + bounds[3]) / 2)  # (lon, lat)
     return center
@@ -797,7 +913,7 @@ def stac_bands(
         url (str): HTTP URL to a STAC item, e.g., https://canada-spot-ortho.s3.amazonaws.com/canada_spot_orthoimages/canada_spot5_orthoimages/S5_2007/S5_11055_6057_20070622/S5_11055_6057_20070622.json
         collection (str): The Microsoft Planetary Computer STAC collection ID, e.g., landsat-8-c2-l2.
         item (str): The Microsoft Planetary Computer STAC item ID, e.g., LC08_L2SP_047027_20201204_02_T1.
-        titiler_endpoint (str, optional): Titiler endpoint, e.g., "https://titiler.xyz", "planetary-computer", "pc". Defaults to None.
+        titiler_endpoint (str, optional): TiTiler endpoint, e.g., "https://giswqs-titiler-endpoint.hf.space", "planetary-computer", "pc". Defaults to None.
 
     Returns:
         list: A list of band names
@@ -809,6 +925,12 @@ def stac_bands(
     if collection is not None and titiler_endpoint is None:
         titiler_endpoint = "planetary-computer"
 
+    if isinstance(url, pystac.Item):
+        try:
+            url = url.self_href
+        except Exception as e:
+            print(e)
+
     if url is not None:
         kwargs["url"] = url
     if collection is not None:
@@ -840,7 +962,7 @@ def stac_stats(
         collection (str): The Microsoft Planetary Computer STAC collection ID, e.g., landsat-8-c2-l2.
         item (str): The Microsoft Planetary Computer STAC item ID, e.g., LC08_L2SP_047027_20201204_02_T1.
         assets (str | list): The Microsoft Planetary Computer STAC asset ID, e.g., ["SR_B7", "SR_B5", "SR_B4"].
-        titiler_endpoint (str, optional): Titiler endpoint, e.g., "https://titiler.xyz", "planetary-computer", "pc". Defaults to None.
+        titiler_endpoint (str, optional): TiTiler endpoint, e.g., "https://giswqs-titiler-endpoint.hf.space", "planetary-computer", "pc". Defaults to None.
 
     Returns:
         list: A dictionary of band statistics.
@@ -852,6 +974,12 @@ def stac_stats(
     if collection is not None and titiler_endpoint is None:
         titiler_endpoint = "planetary-computer"
 
+    if isinstance(url, pystac.Item):
+        try:
+            url = url.self_href
+        except Exception as e:
+            print(e)
+
     if url is not None:
         kwargs["url"] = url
     if collection is not None:
@@ -887,7 +1015,7 @@ def stac_min_max(
         collection (str): The Microsoft Planetary Computer STAC collection ID, e.g., landsat-8-c2-l2.
         item (str): The Microsoft Planetary Computer STAC item ID, e.g., LC08_L2SP_047027_20201204_02_T1.
         assets (str | list): The Microsoft Planetary Computer STAC asset ID, e.g., ["SR_B7", "SR_B5", "SR_B4"].
-        titiler_endpoint (str, optional): Titiler endpoint, e.g., "https://titiler.xyz", "planetary-computer", "pc". Defaults to None.
+        titiler_endpoint (str, optional): TiTiler endpoint, e.g., "https://giswqs-titiler-endpoint.hf.space", "planetary-computer", "pc". Defaults to None.
 
     Returns:
         list: A dictionary of band statistics.
@@ -897,10 +1025,13 @@ def stac_min_max(
 
     values = stats.values()
 
-    min_values = [v["min"] for v in values]
-    max_values = [v["max"] for v in values]
+    try:
+        min_values = [v["min"] for v in values]
+        max_values = [v["max"] for v in values]
 
-    return min(min_values), max(max_values)
+        return min(min_values), max(max_values)
+    except Exception as e:
+        return None, None
 
 
 def stac_info(
@@ -918,7 +1049,7 @@ def stac_info(
         collection (str): The Microsoft Planetary Computer STAC collection ID, e.g., landsat-8-c2-l2.
         item (str): The Microsoft Planetary Computer STAC item ID, e.g., LC08_L2SP_047027_20201204_02_T1.
         assets (str | list): The Microsoft Planetary Computer STAC asset ID, e.g., ["SR_B7", "SR_B5", "SR_B4"].
-        titiler_endpoint (str, optional): Titiler endpoint, e.g., "https://titiler.xyz", "planetary-computer", "pc". Defaults to None.
+        titiler_endpoint (str, optional): TiTiler endpoint, e.g., "https://giswqs-titiler-endpoint.hf.space", "planetary-computer", "pc". Defaults to None.
 
     Returns:
         list: A dictionary of band info.
@@ -930,6 +1061,12 @@ def stac_info(
     if collection is not None and titiler_endpoint is None:
         titiler_endpoint = "planetary-computer"
 
+    if isinstance(url, pystac.Item):
+        try:
+            url = url.self_href
+        except Exception as e:
+            print(e)
+
     if url is not None:
         kwargs["url"] = url
     if collection is not None:
@@ -963,7 +1100,7 @@ def stac_info_geojson(
         collection (str): The Microsoft Planetary Computer STAC collection ID, e.g., landsat-8-c2-l2.
         item (str): The Microsoft Planetary Computer STAC item ID, e.g., LC08_L2SP_047027_20201204_02_T1.
         assets (str | list): The Microsoft Planetary Computer STAC asset ID, e.g., ["SR_B7", "SR_B5", "SR_B4"].
-        titiler_endpoint (str, optional): Titiler endpoint, e.g., "https://titiler.xyz", "planetary-computer", "pc". Defaults to None.
+        titiler_endpoint (str, optional): TiTiler endpoint, e.g., "https://giswqs-titiler-endpoint.hf.space", "planetary-computer", "pc". Defaults to None.
 
     Returns:
         list: A dictionary of band info.
@@ -975,6 +1112,12 @@ def stac_info_geojson(
     if collection is not None and titiler_endpoint is None:
         titiler_endpoint = "planetary-computer"
 
+    if isinstance(url, pystac.Item):
+        try:
+            url = url.self_href
+        except Exception as e:
+            print(e)
+
     if url is not None:
         kwargs["url"] = url
     if collection is not None:
@@ -1008,7 +1151,7 @@ def stac_assets(
         url (str): HTTP URL to a STAC item, e.g., https://canada-spot-ortho.s3.amazonaws.com/canada_spot_orthoimages/canada_spot5_orthoimages/S5_2007/S5_11055_6057_20070622/S5_11055_6057_20070622.json
         collection (str): The Microsoft Planetary Computer STAC collection ID, e.g., landsat-8-c2-l2.
         item (str): The Microsoft Planetary Computer STAC item ID, e.g., LC08_L2SP_047027_20201204_02_T1.
-        titiler_endpoint (str, optional): Titiler endpoint, e.g., "https://titiler.xyz", "planetary-computer", "pc". Defaults to None.
+        titiler_endpoint (str, optional): TiTiler endpoint, e.g., "https://giswqs-titiler-endpoint.hf.space", "planetary-computer", "pc". Defaults to None.
 
     Returns:
         list: A list of assets.
@@ -1020,6 +1163,12 @@ def stac_assets(
     if collection is not None and titiler_endpoint is None:
         titiler_endpoint = "planetary-computer"
 
+    if isinstance(url, pystac.Item):
+        try:
+            url = url.self_href
+        except Exception as e:
+            print(e)
+
     if url is not None:
         kwargs["url"] = url
     if collection is not None:
@@ -1056,7 +1205,7 @@ def stac_pixel_value(
         collection (str): The Microsoft Planetary Computer STAC collection ID, e.g., landsat-8-c2-l2.
         item (str): The Microsoft Planetary Computer STAC item ID, e.g., LC08_L2SP_047027_20201204_02_T1.
         assets (str | list): The Microsoft Planetary Computer STAC asset ID, e.g., ["SR_B7", "SR_B5", "SR_B4"].
-        titiler_endpoint (str, optional): Titiler endpoint, e.g., "https://titiler.xyz", "planetary-computer", "pc". Defaults to None.
+        titiler_endpoint (str, optional): TiTiler endpoint, e.g., "https://giswqs-titiler-endpoint.hf.space", "planetary-computer", "pc". Defaults to None.
         verbose (bool, optional): Print out the error message. Defaults to True.
 
     Returns:
@@ -1069,6 +1218,12 @@ def stac_pixel_value(
     if collection is not None and titiler_endpoint is None:
         titiler_endpoint = "planetary-computer"
 
+    if isinstance(url, pystac.Item):
+        try:
+            url = url.self_href
+        except Exception as e:
+            print(e)
+
     if url is not None:
         kwargs["url"] = url
     if collection is not None:
@@ -1138,33 +1293,76 @@ def stac_root_link(url: str, return_col_id: Optional[bool] = False, **kwargs) ->
 
     Args:
         url (str): The STAC object URL.
-        return_col_id (bool, optional): Return the collection ID if the STAC object is a collection. Defaults to False.
-        **kwargs: Keyword arguments for pystac.STACObject.from_file(). Defaults to None.
+        return_col_id (bool, optional): Return the collection ID if the STAC object
+            is a collection. Defaults to False.
+        **kwargs: Keyword arguments for pystac.STACObject.from_file().
 
     Returns:
-        str: The root link of the STAC object.
+        str: The root link of the STAC object. Returns None if no root link found.
+        tuple: If return_col_id is True, returns (root_link, collection_id).
+
+    Raises:
+        ValueError: If FeatureCollection contains no features.
     """
     collection_id = None
     try:
-        obj = pystac.STACObject.from_file(url, **kwargs)
-        if isinstance(obj, pystac.Collection):
-            collection_id = obj.id
-        href = obj.get_root_link().get_href()
+        response = requests.get(url, **kwargs)
+        response.raise_for_status()
+        data = response.json()
 
-        if not url.startswith(href):
-            href = obj.get_self_href()
+        # Handle FeatureCollection from /items endpoint
+        if data.get("type") == "FeatureCollection":
+            features = data.get("features", [])
+            if not features:
+                raise ValueError("FeatureCollection contains no features.")
+            item = pystac.Item.from_dict(features[0])
+            collection_id = item.collection_id
+            root = item.get_root_link()
+            return (
+                (root.get_href() if root else item.get_self_href(), collection_id)
+                if return_col_id
+                else root.get_href() if root else item.get_self_href()
+            )
 
+        # Handle STAC API objects (Collection, Catalog, etc.)
+        links = data.get("links", [])
+        root_href = None
+        self_href = None
+
+        for link in links:
+            if link.get("rel") == "root":
+                root_href = link.get("href")
+            elif link.get("rel") == "self":
+                self_href = link.get("href")
+
+        # Get collection/catalog ID if requested
         if return_col_id:
-            return href, collection_id
-        else:
-            return href
+            if data.get("type") in ["Collection", "Catalog"]:
+                collection_id = data.get("id")
+
+        # Determine the root href:
+        # 1. If there's an explicit root link, use it
+        # 2. If there's no root link but there's a self link, the self link is the root
+        #    (this is common for root catalogs in STAC APIs)
+        # 3. Otherwise, fall back to parsing as a regular STAC object
+        if root_href:
+            return (root_href, collection_id) if return_col_id else root_href
+        elif self_href and not root_href:
+            # When there's no root link, self link often indicates this IS the root
+            return (self_href, collection_id) if return_col_id else self_href
+
+        # Fallback: parse as regular STAC object using pystac
+        obj = pystac.STACObject.from_dict(data)
+        if isinstance(obj, (pystac.Collection, pystac.Catalog)):
+            collection_id = obj.id
+
+        root = obj.get_root_link()
+        href = root.get_href() if root else obj.get_self_href()
+        return (href, collection_id) if return_col_id else href
 
     except Exception as e:
-        print(e)
-        if return_col_id:
-            return None, None
-        else:
-            return None
+        print(f"Failed to resolve STAC root from {url}: {e}")
+        return (None, None) if return_col_id else None
 
 
 def stac_client(
@@ -1220,6 +1418,12 @@ def stac_client(
     try:
         if get_root:
             root = stac_root_link(url, return_col_id=return_col_id)
+            # Handle case where root is None
+            if root is None:
+                if return_col_id:
+                    root = (url, None)
+                else:
+                    root = url
         else:
             root = url
 
@@ -1450,7 +1654,7 @@ def stac_search_to_gdf(search, **kwargs):
     return gdf
 
 
-def stac_search_to_df(search, **kwargs) -> DataFrame:
+def stac_search_to_df(search, **kwargs) -> pd.DataFrame:
     """Convert STAC search result to a DataFrame.
 
     Args:
@@ -1824,7 +2028,7 @@ def maxar_all_items(
             if child_id == child_ids[0]:
                 gdf = items
             else:
-                gdf = gdf.append(items)
+                gdf = pd.concat([gdf, items], ignore_index=True)
         else:
             if child_id == child_ids[0]:
                 items_all = items
@@ -2116,10 +2320,8 @@ def oam_search(
         GeoDataFrame | list: If return_gdf is True, return a GeoDataFrame. Otherwise, return a list.
     """
 
-    if return_gdf:
-        import pandas as pd
-        from shapely.geometry import Polygon
-        import geopandas as gpd
+    from shapely.geometry import Polygon
+    import geopandas as gpd
 
     url = "https://api.openaerialmap.org/meta"
     if bbox is not None:
@@ -2171,3 +2373,87 @@ def oam_search(
 
     except Exception as e:
         return None
+
+
+def _get_image_colormap(image, index=1):
+    """
+    Retrieve the colormap from an image.
+
+    Args:
+        image (str, rasterio.io.DatasetReader, rioxarray.DataArray):
+            The input image. It can be:
+            - A file path to a raster image (string).
+            - A rasterio dataset.
+            - A rioxarray DataArray.
+        index (int): The band index to retrieve the colormap from (default is 1).
+
+    Returns:
+        dict: A dictionary representing the colormap (value: (R, G, B, A)), or None if no colormap is found.
+
+    Raises:
+        ValueError: If the input image type is unsupported.
+    """
+    import rasterio
+    import rioxarray
+    import xarray as xr
+
+    def remove_black_fills(d: dict) -> dict:
+        """Remove keys with value (0, 0, 0, 255)."""
+        return {str(k): v for k, v in d.items() if v != (0, 0, 0, 255)}
+
+    dataset = None
+
+    if isinstance(image, str):  # File path
+        with rasterio.open(image) as ds:
+            try:
+                return remove_black_fills(ds.colormap(index)) if ds.count > 0 else None
+            except:
+                return None
+    elif isinstance(image, rasterio.io.DatasetReader):  # rasterio dataset
+        dataset = image
+    elif isinstance(image, xr.DataArray) or isinstance(image, xr.Dataset):
+        source = image.encoding.get("source")
+        if source:
+            with rasterio.open(source) as ds:
+                return remove_black_fills(ds.colormap(index)) if ds.count > 0 else None
+        else:
+            raise ValueError(
+                "Cannot extract colormap: DataArray does not have a source."
+            )
+    else:
+        raise ValueError(
+            "Unsupported input type. Provide a file path, rasterio dataset, or rioxarray DataArray."
+        )
+
+    if dataset:
+        return (
+            remove_black_fills(dataset.colormap(index)) if dataset.count > 0 else None
+        )
+
+
+def get_cog_link_from_stac_item(item_url: str) -> str:
+    """
+    Retrieve the URL of the GeoTIFF asset from a STAC Item.
+
+    Args:
+        item_url (str): The URL to a STAC Item JSON.
+
+    Returns:
+        str: URL of the first .tif asset, or None if not found.
+    """
+    try:
+        response = requests.get(item_url)
+        response.raise_for_status()
+        item = response.json()
+
+        # Look for any asset ending in .tif
+        for asset_key, asset in item.get("assets", {}).items():
+            href = asset.get("href", "")
+            if href.endswith(".tif") or ".tif?" in href:
+                return href
+
+        print("No .tif asset found in item.")
+        return None
+    except Exception as e:
+        print(f"Failed to retrieve STAC item: {e}")
+        return None
